capture log close
set matsize 500
set more off
log using st4ch2stata6.log, replace

***
*** RM4STATA Ch 2: Introduction to Stata - 3/9/01
***
*** For Stata 6
***

*** Section 2.8: using and saving datasets
use nomocc2.dta, clear
save nomocc3.dta, replace

*** Section 2.10: command or do files

** example.do: short do file

/*
    log using example, replace
    use binlfp2, clear
    tabulate hc wc, row nolabel
    log close
*/

** example2.do: short do file using comments

/*
    /*
    ==> short simple do file
    ==> for didactic purposes
    */
    log using example, replace  /* this text is ignored */
    * next we load the data
    use binlfp2, clear
    * tabulate husband's and wife's education
    tabulate hc wc, row nolabel
    * close up
    log close
    * make sure there is a cr at the end!
*/

** long lines using #delimit
use gsskidvalue2.dta
#delimit ;
recode income91 1=500 2=1500 3=3500 4=4500 5=5500 6=6500 7=7500 8=9000
9=11250 10=13750 11=16250 12=18750 13=21250 14=23750 15=27500 16=32500
17=37500 18=45000 19=55000 20=67500 21=75000 *=. ;
#delimit cr

** Tip: long lines
recode income91 1=500 2=1500 3=3500 4=4500 5=5500 6=6500 7=7500 8=9000 /*
*/ 9=11250 10=13750 11=16250 12=18750 13=21250 14=23750 15=27500 16=32500 /*
*/ 17=37500 18=45000 19=55000 20=67500 21=75000 *=.

*** Section 2.10.2: recommended structure of do files

/*
* Note: version number ensures compatibility with later Stata releases
version 7
* Note: if a log file is open, close it
capture log close
* Note: don't pause when output scrolls off the page
set more off
* Note: log results to file myfile.log
log using myfile, replace text
* myfile.do - written 19 jan 2001 to illustrate do files

* Note: your commands go here

* Note: close the log file.
log close
*/

*** Section 2.12: syntax of stata commands
use binlfp2, clear
tabulate hc wc if age>40, row

*** Section 2.12.2: variable lists
sum age inc k5
sum
sum k*

*** Section 2.12.3: if and in
use gsskidvalue2, clear
sum income if age>=25 & age<=65
sum income if age>=25 & age<=65 & female==1
sum income if (age<25 | age>65) & age~=. & female==1

*** Section 2.13.2: getting information
use binlfp2, clear
describe
sum age, detail
tab hc
tab hc, nolabel
tab hc wc
tab1 hc wc
dotplot age
codebook age

*** Section 2.14.1: generate
use binlfp2, clear
generate age2 = age
summarize age2 age
gen age3 = age if age>40
sum age3 age
gen agesq = age^2
gen lnage = ln(age)

*** Section 2.14.2: replace
gen age4 = age
replace age4 = 40 if age<40
sum age4 age

*** Section 2.14.3: recode
use recodedata2.dta, clear
gen myvar1 = origvar
recode myvar1 1=2 3=4
gen myvar2 = origvar
recode myvar2 2=1 *=0
gen myvar3 = origvar
recode myvar3 2=1 *=0 if myvar3~=.
gen myvar4 = origvar
recode myvar4 1/4=2
gen myvar5 = origvar
recode myvar5 1 3 4 5=7
gen myvar6 = origvar
recode myvar6 min/5=min
gen myvar7 = origvar
recode myvar7 .=9

*** Secton 2.14.4: common transformations of rhs variables

** breaking a categorical variable into a set of dummy variables
use gsskidvalue2, clear
* example 1 - tab, gen()
tab degree, gen(edlevel)
sum edlevel*
tab degree edlevel1, missing
* example 2 - gen if
gen hsdeg = (degree==1 | degree==2) if degree~=.
gen coldeg = (degree==3) if degree~=.
gen graddeg = (degree==4) if degree~=.
tab degree coldeg , missing

** more examples of creating binary variables
use ordwarm2, clear
* example 1 - a single binary variable
gen ed12plus = (ed>=12) if ed~=.
* example 2 - three indicator variables
gen edlt13 = (ed<=12) if ed~=.
gen ed1316 = (ed>=13 & ed<=16) if ed~=.
gen ed17plus = (ed>17) if ed~=.
*  example 3 - recode to a binary outcome
gen wrmagree = warm
recode wrmagree 1=0 2=0 3=1 4=1
tab wrmagree warm

** nonlinear transformations
use gsskidvalue2, clear
gen agesq = age*age
gen lnincome = ln(income)
sum age agesq income lnincome

** interaction terms
gen feminc = female * income

*** Section 2.15.1: variable label
** adding a label
label variable agesq "Age squared"
describe agesq
** deleting a label
label variable agesq
describe agesq

*** Section 2.15.2: value labels

** defining labels
label define yesno 1 yes 0 no
label define posneg4 1 veryN 2 negative 3 positive 4 veryP
label define agree4 1 StrongA 2 Agree 3 Disagree 4 StrongD
label define agree5 1 StrongA 2 Agree 3 Neutral 4 Disagree 5 StrongD

** assigning labels
label values female yesno
label values black yesno
label values anykids yesno
describe female black anykids
tab anykids

** defining and assigning labels
label define degree 0 "no_hs" 1 "hs" 2 "jun_col" 3 "bachelor" 4 "graduate"
label values degree degree
tab degree

*** Section 2.15.3: notes

** assign notes
notes: small General Social Survey extract for Stata book
notes income: self-reported family income, measured in dollars
notes income: refusals coded as missing

** list notes
notes

*** Section 2.16.1: the graph command
use lfpgraph2, clear
list income kid0p1 kid1p1 kid2p1

** a simple graph
graph kid0p1 kid1p1 kid2p1 income

** illustration of the various labels
graph kid0p1 kid1p1 kid2p1 income, l1title("l1title") l2title("l2title") /*
*/ t1title("t1title") t2title("t2title") b1title("b1title") /*
*/ b2title("b2title") r1title("r1title") r2title("r2title")

** putting everything together
set textsize 125
#delimit ;
graph kid0p1 kid1p1 kid2p1 income, s(OTp) c(lll) xlabel(10 30 to 90)
xtick (20 40 60 80) ylabel (0 .2 to 1) l2title("Probability") gap(3)
saving(mygraph, replace);
#delimit cr

** exporting graphs to other programs
gphprint, saving(mygraph.wmf, replace)

*** Section 2.16.3: Combining Graphs
#delimit ;
graph kid0p1 kid1p1 kid2p1 income, s(...) c(lll) xlabel(10 30 to 90)
xtick (20 40 60 80) ylabel (0 .2 to 1) l2title("Probability") gap(3)
saving(mygraph2, replace);
#delimit cr
graph using mygraph mygraph2, saving(mygraphsbs, replace)
gphprint, saving(mygraphsbs.wmf, replace)
graph using, saving(null, replace)
graph using mygraph null mygraph2, saving(mygraphvert, replace)
gphprint, saving(mygraphvert.wmf, replace)

*** Section 2.17: tutorial - see st4ch2tutorial.do

log close
