capture log close
set matsize 500
set more off
log using st4ch4residgraphstata6, replace

***
*** RM4STATA Ch 4: Models for Binary Outcomes - 3/9/01
***
*** For Stata 6
***

*** Section 4.5: Figure 4.3

** create artificial data
clear
set seed 315
set obs 34
gen y = (uniform()*4) in 1/30
gen x = (4 - (y)) + (uniform()) in 1/30
* change one point
replace y = 9 in 31
sum x
sca meanx = r(mean)
replace x = meanx in 31
* compute the regression
reg y x
* change two points
replace x = 0 in 32
replace x = 5 in 33
* compute predictions
predict yhat in 32/33
gen y3 = 9 in 31
set textsize 150

* graph the predictions and some outliers
graph y yhat y3 x, xlabel(0 5 10) ylabel(0 5 10) s(o.S) c(.l[-].) /*
*/ pen(222) title("Large outlier that is not influential in LRM") /*
*/ key1(c(l[-]) "Regression line") key2("") key3("") gap(2) /*
*/ b2title("x") l2title("y") saving(04resida, replace)

** change the data
replace y = 29 in 31
replace x = 29.5 in 31
replace x = 30 in 34
replace y3 = 29 in 31
* compute the regression
reg y x
predict yhat2
* graph the results
graph y yhat2 yhat y3 x, xlabel(0 15 30) ylabel(0 15 30) s(o..S) /*
*/ c(.ll[-].) pen(2222) title("Smaller outlier that is influential in LRM") /*
*/ key1(c(l[-]) "Old regression line") /*
*/ key2(c(l[l]) "New regression line") key3("") /*
*/ gap(2) b2title("x") l2title("y") saving(04residb, replace)

** combine the two graphs
graph using, saving(null, replace)
graph using 04resida null 04residb
gphprint, saving(04residstata.wmf, replace)

log close
