capture log close
set matsize 500
set more off
log using st4ch4stata6, replace

***
*** RM4STATA Ch 4: Models for Binary Outcomes - 3/9/01
***
*** For Stata 6
***

*** Section 4.3: estimation using -logit- and -probit-
use binlfp2, clear
desc lfp k5 k618 age wc hc lwg inc
summarize lfp k5 k618 age wc hc lwg inc
logit lfp k5 k618 age wc hc lwg inc, nolog
outreg using 04lgtpbt, replace
probit lfp k5 k618 age wc hc lwg inc, nolog
outreg using 04lgtpbt, append

*** Section 4.3.1: predicting perfectly (using artificial data)
use science2, clear
gen college = 1-mmale
gen vote = pub1>10
tab vote college
logit vote college phd, nolog

*** Section 4.4.1: testing individual coefficients
use binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc, nolog

** Wald test
test k5
display sqrt(55.14)

** LR test
logit lfp k5 k618 age wc hc lwg inc, nolog
lrtest, saving(0)
logit lfp k618 age wc hc lwg inc, nolog
lrtest

*** Section 4.4.2: testing multiple coefficients
logit lfp k5 k618 age wc hc lwg inc, nolog

** Wald tests
test hc wc
test hc=wc

** LR tests
logit lfp k5 k618 age wc hc lwg inc, nolog
lrtest, saving(0)
logit lfp k5 k618 age lwg inc, nolog
lrtest
logit lfp, nolog
lrtest

*** Section 4.5: residuals and influence using -predict-
*=> To construct Figure 4.3, see st4ch4residgraph.do

*** Section 4.5.1: residuals
use binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc, nolog
predict rstd, rs
label var rstd "Standardized Residual"
**
**  Advanced Note: we create a tempvar so that -sort- will produce exactly
**  the same results every time. This is because -sort- breaks ties randomly.
**
gen tempvar = _n
sort inc tempvar
drop tempvar
generate index = _n
label var index "Observation Number"
set textsize 125

** index plot of std pearson residuals
graph rstd index, s(o) xscale(0,800) yscale(-4,4) yline(0) gap(4) /*
*/ xlabel(0,200,400,600,800) ylabel(-4,-2,0,2,4) b2("Observation Number")
gphprint, saving(04rstd.wmf, replace)
set textsize 125

** index plot of std pearson residuals labeled with the index
graph rstd index, s([index]) xscale(0,800) yscale(-4,4) yline(0) gap(4) /*
*/ xlabel(0,200,400,600,800) ylabel(-4,-2,0,2,4) b2("Observation Number")
gphprint, saving(04rstdcase.wmf, replace)

** list a single point
list in 142

** list large outliers
list rstd index if rstd>2.5 | rstd<-2.5

*** Section 4.5.2: influential cases
predict cook,dbeta
label var cook "Cook's Statistic"
graph cook index, s([index]) xscale(0,800) yscale(0,.3) yline(.1,.2) gap(3) /*
*/ xlabel(0,200,400,600,800) ylabel(0,.1,.2,.3) b2("Observation Number")
gphprint, saving(04cookcase.wmf, replace)

*** Section 4.6: scalar measures of fit
quietly logit lfp k5 k618 age wc hc lwg inc, nolog
outreg using 04fit, replace nolabel
quietly fitstat, save
gen agesq = age*age
logit lfp k5 age agesq wc inc, nolog
outreg using 04fit, append nolabel
fitstat, dif

*** Section 4.7.1: in sample predicted probabilities

** predictions from -logit-
use binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc, nolog
predict prlogit
summarize prlogit
label var prlogit "Logit: Pr(lfp)"
dotplot prlogit, ylabel(0 .2 to 1) gap(3)

** comparing -logit- and -probit- predictions
use binlfp2, clear
logit lfp k5 k618 age wc hc lwg inc, nolog
predict prlogit
label var prlogit "Logit: Pr(lfp)"
probit lfp k5 k618 age wc hc lwg inc, nolog
predict prprobit
label var prprobit "Probit: Pr(lfp)"
pwcorr prlogit prprobit

** graphing predicted probabilities from -logit- and -probit-
graph prlogit prprobit, gap(4) /*
*/ xscale(0,1) yscale(0,1) yline(.25,.5,.75,1) xline(.25,.5,.75,1)
gphprint, saving(04logitprobit.wmf, replace)

*** Section 4.7.2: individual predicted probabilities with -prvalue-
logit lfp k5 k618 age wc hc lwg inc, nolog

** young, low income, low education families with young children.
prvalue, x(age=35 k5=2 wc=0 hc=0 inc=15) rest(mean)

** highly education families with no children at home.
prvalue, x(age=50 k5=0 k618=0 wc=1 hc=1) rest(mean)

** an average person
prvalue, rest(mean)

*** Section 4.7.3: tables of predicted probabilities with -prtab-
logit lfp k5 k618 age wc hc lwg inc, nolog

** using -prvalue-
prvalue, x(k5=0 wc=0) rest(mean) brief
prvalue, x(k5=1 wc=0) rest(mean) brief
prvalue, x(k5=2 wc=0) rest(mean) brief
prvalue, x(k5=3 wc=0) rest(mean) brief

** or use -prtab-
prtab k5 wc, rest(mean)

** compute the differences:
di 0.6069-0.7758
di 0.2633-0.4449
di 0.0764-0.1565
di 0.0188-0.0412

*** Section 4.7.4: graphing predicted probabilities with -prgen-

** compute predictions at different ages
* age 30
prgen inc, from(0) to(100) generate(p30) x(age=30) rest(mean) n(11)
label var p30p1 "Age 30"
* age 40
prgen inc, from(0) to(100) generate(p40) x(age=40) rest(mean) n(11)
label var p40p1 "Age 40"
* age 50
prgen inc, from(0) to(100) generate(p50) x(age=50) rest(mean) n(11)
label var p50p1 "Age 50"
* age 60
prgen inc, from(0) to(100) generate(p60) x(age=60) rest(mean) n(11)
label var p60p1 "Age 60"

** -list- and -graph- predictions
list p30p1 p40p1 p50p1 p60p1 p60x in 1/11
set textsize 125
graph p30p1 p40p1 p50p1 p60p1 p60x, gap(4) s(pdST) connect(ssss) /*
*/ b2("Income") xlabel(0,20,40,60,80,100) xscale(0,100) /*
*/ l2("Pr(In Labor Force)") ylabel(0,.25,.50,.75,1) yscale(0,1)
gphprint, saving(04ageincome.wmf, replace)


** another example of -prgen- comparing those who do and do not attend college
prgen age, from(30) to(60) generate(wc1) x(wc=1) rest(mean) n(13)
label var wc1p1 "Attended College"
prgen age, from(30) to(60) generate(wc0) x(wc=0) rest(mean) n(13)
label var wc0p1 "Did Not Attend College"
set textsize 125
#delimit ;
graph wc1p1 wc0p1 wc1x,
s(pd) b2("Age") l2("Pr(In Labor Force)")
xlabel(30,35,40,45,50,55,60) ylabel(0,.25,.50,.75,1)
xscale(30,60) yscale(0,1) connect(ss) gap(3);
#delimit cr;

*** Section 4.7.5: changes in predicted probabilities

** discrete change with -prchange-
prchange age, x(wc=1 age=40)
prchange, help
prchange k5 age lwg inc, fromto

** discrete change using -prvalue-
prvalue, x(age=30) save brief
prvalue, x(age=40) dif brief

** discrete change using -prchange- with -delta- and -uncentered- options
prchange age, x(age=30) uncentered delta(10) rest(mean) brief

*** Section 4.7.6: odds ratios using -listcoef-
listcoef, help
listcoef, reverse
listcoef, percent

log close
